\name{boolean}
\alias{boolean}
\alias{Boolean}
\title{ Partial-Observability Logit or Probit Models for Testing 
  Boolean Hypotheses }
\description{
  Boolean logit and probit are a family of partial-observability
  \emph{n}-variate models designed to permit researchers to model
  causal complexity, or multiple causal "paths" to a given outcome
  (e.g., a situation in which either a or b will produce y, one in
  which (a or b) and c produce y, and so forth).
}
\usage{
boolean(structure, method, maxoptions = "", optimizer="nlm",
        safety=1, bootstrap=FALSE, bootsize=100)
}
\arguments{
  \item{structure}{ 
  Structure of equation to be estimated, in standard y ~ f(x) form,
  using \code{&} to represent the Boolean operator "and" and \code{|}
  to represent the Boolean operator "or."  (Note that the syntax
  requires that constants be entered explicitly; see the entry for
  \code{\link{boolprep}} for details.)  Be sure to enter the correct
  functional form and balance parentheses; if in doubt, or just for
  convenience, use the \code{boolprep} command to prepare structure
  prior to estimation. }
  \item{method}{ Either "logit" or "probit". }
  \item{maxoptions}{ Maximization options (see \code{\link{nlm}} or
  \code{\link{optim}} for details). }
  \item{optimizer}{ Either "nlm" or "optim". }
  \item{safety}{ Number of search attempts.  The likelihood functions
  implied by Boolean procedures can become quite convoluted; in such
  cases, multiple searches from different starting points can be run.
  Works only when using \code{nlm}. }
  \item{bootstrap}{ If TRUE, bootstraps standard errors. }
  \item{bootsize}{ Number of iterations if bootstrap=TRUE. }
}
\details{
  Boolean permits estimation of Boolean logit and probit equations
  (see Braumoeller 2003 for derivation).  Boolean logit and probit
  model situations in which any number of antecedent conditions
  (a, b, c, ...) occur with probabilities that can be modeled using
  standard logit or probit curves, and the antecedent conditions
  combine in a manner described by Boolean logic to produce the
  dependent variable.  For example, theory might suggest that a binary
  dependent variable y occurs only when conditions a and b are present,
  that the probability of a's occurrence is influenced by variables
  x1...x4, and that the probability of b's occurrence is influenced by
  variables x5...x8.  Alternately, theory might suggest that y occurs
  if (a and b) or (c and d) are present (in other words, that a-d are
  INUS conditions; see Mackie 1965), and that the probability of the
  occurrence of each antecedent condition is influenced by some vector
  of independent variables.  Boolean logit and probit are designed for
  use in such situations.
}
\value{
  Returns an object of class booltest, with slots @Calculus, @LogLik,
  @Variables, @Coefficients, @StandardErrors, @Iterations, @Hessian,
  @Gradient, @Zscore, @Probz, @Conf95lo, @Conf95hi, @pstructure, and
  @method (note that some slots may be left empty if the relevant
  information is not furnished by the maximizer).
}
\references{
  Braumoeller, Bear F. (2003) "Causal Complexity and the Study
  of Politics." \emph{Political Analysis} 11(3): 209-233.

  Mackie, J. L. (1965) "Causes and Conditions." \emph{American
  Philosophical Quarterly} 2(4): 245-264.
}
\author{
Bear F. Braumoeller, Harvard University, \email{bfbraum@fas.harvard.edu} \cr
Jacob Kline, Harvard University, \email{jkline@fas.harvard.edu}
}
\note{ Examining profile likelihoods with \code{boolprof} is highly
  recommended.  Boolean logit and probit are partial observability models,
  which are generically starved for information; as a result, maximum
  likelihood estimation can encounter problems with plateaus in likelihood
  functions even with very large n. }

\seealso{ \code{\link{boolprep}} to prepare structure of equation,
  \code{\link{boolfirst}} to graph first differences after estimation, and
  \code{\link{boolprof}} to produce profile likelihoods after estimation. }

\examples{
library("boolean")
set.seed(50)
x1<-rnorm(1000)
x2<-rnorm(1000)
x3<-rnorm(1000)
x4<-rnorm(1000)
x5<-rnorm(1000)
x6<-rnorm(1000)
e1<-rnorm(1000)/3
e2<-rnorm(1000)/3
e3<-rnorm(1000)/3
y<-1-(1-pnorm(-2+0.33*x1+0.66*x2+1*x3+e1)*1-(pnorm(1+1.5*x4-0.25*x5+e2)*pnorm(1+0.2*x6+e3)))
y <- y>runif(1000)
answer <- boolean(y ~( ((cons+x1+x2+x3)|((cons+x4+x5)&(cons+x6))) ), method="probit")

## Examine coefficients, standard errors, etc.
summary(answer)

## Examine "summary" output plus Hessian, gradient, etc.
show(answer)

## Plot first differences for model
plot(answer)

## Plot profiles
plot(answer, panel="boolprof")
}
\keyword{logic}
\keyword{optimize}
\keyword{distribution}
\keyword{models}
\eof
\name{boolfirst}
\alias{boolfirst}
\title{ Graph First Differences after Boolean Logit/Probit }
\description{
  This function graphs first differences for a given variable,
  with all other variables held at their means, following the
  execution of a \code{\link{boolean}} logit or probit command.
}
\usage{
boolfirst(object, gvar, instance = 0, range = 0)
}
\arguments{
  \item{object}{ The object created by the boolean command. }
  \item{gvar}{ Name of variable associated with coefficient of
     interest. }
  \item{instance}{ If variable occurs more than once in equation,
     permits user to specify which occurrence corresponds to the
     coefficient of interest. }
  \item{range}{ Range of points over which graph is plotted (e.g.,
  range=seq(0,1,0.01)) }
}
\references{ Braumoeller, Bear F. (2003) "Causal Complexity and the
     Study of Politics." \emph{Political Analysis} 11(3): 209-233. }

\author{
Bear F. Braumoeller, Harvard University, \email{bfbraum@fas.harvard.edu} \cr
Jacob Kline, Harvard University, \email{jkline@fas.harvard.edu}
}

\seealso{ \code{\link{boolean}}, \code{\link{boolprep}}, 
     and \code{\link{boolprof}}. }

\examples{
library("boolean")
set.seed(50)
x1<-rnorm(1000)
x2<-rnorm(1000)
x3<-rnorm(1000)
x4<-rnorm(1000)
x5<-rnorm(1000)
x6<-rnorm(1000)
e1<-rnorm(1000)/3
e2<-rnorm(1000)/3
e3<-rnorm(1000)/3
y<-1-(1-pnorm(-2+0.33*x1+0.66*x2+1*x3+e1)*1-(pnorm(1+1.5*x4-0.25*x5+e2)*pnorm(1+0.2*x6+e3)))
y <- y>runif(1000)
answer <- boolean(y ~( ((cons+x1+x2+x3)|((cons+x4+x5)&(cons+x6))) ), method="probit")
boolfirst(answer, "x4")
boolprof(answer, "x1", instance=2)
}
\keyword{logic}
\keyword{optimize}
\keyword{distribution}
\keyword{models}
\eof
\name{boolprep}
\alias{boolprep}
\title{ Generate Functional Form for Boolean Logit or Probit }
\description{
  Takes as arguments the logical form of a Boolean model, the
  dependent variable, and the vectors of independent variables, and
  produces a functional form suitable for inclusion in a
  \code{\link{boolean}} logit or probit command.
}
\usage{
boolprep(form, depvar, a, b = "", c = "", d = "", e = "", f = "",
g = "", h = "", i = "", j = "", k = "", l = "", m = "", n = "",
o = "", p = "", q = "", r = "", s = "", t = "", u = "", v = "",
w = "", x = "", y = "", z = "", constant = TRUE)
}
\arguments{
  \item{form}{ Form of Boolean model, e.g., \code{a&b}, 
     \code{a&(b|c)}, etc. }
  \item{depvar}{ Dependent variable. }
  \item{a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z}{ Vectors
     of independent variables corresponding to \code{a}, \code{b}, etc.,
     in \code{form}. }
  \item{constant}{ Indicates whether constants should be placed in
     each vector of independent variables (note that the syntax
     requires that constant terms be explicitly included). }
}
\details{
  Because the structure of a Boolean logit or probit model can
  be arbitrarily complex, the layering of parentheses soon becomes
  tedious and unnecessarily difficult.  To make life easier, the
  \code{boolprep} command automates the task of creating the
  appropriate argument.
}
\value{
  A text string of the form \code{y ~ f(x1...xn)}.}
}
\references{
  Braumoeller, Bear F. (2003) "Causal Complexity and the Study
  of Politics." \emph{Political Analysis} 11(3): 209-233.
}

\author{
Bear F. Braumoeller, Harvard University, \email{bfbraum@fas.harvard.edu} \cr
Jacob Kline, Harvard University, \email{jkline@fas.harvard.edu}
}

\seealso{ \code{\link{boolean}}, \code{\link{boolprof}}, 
     and \code{\link{boolfirst}}. }

\examples{
boolprep("a&b", "y", "x1+x2", "x3+x4+x5")

boolprep("a|(b&c)", "y", "x1+x2+x3", "x4+x5", "x6")

boolprep("(a|b|c)&(d|e)&f", "y", "x1+x2", "x3+x4+x5", "x6", "x7+x8", "x9+x10+x11", "x12+x13")
}
\keyword{logic}
\keyword{optimize}
\keyword{distribution}
\keyword{models}
\eof
\name{boolprof}
\alias{boolprof}

\title{Graph Profile Likelihoods for Boolean Logit/Probit}
\description{
  This command produces a graph of the profile likelihood for a
  given coefficient following the estimation of a Boolean logit
  or probit model.
}
\usage{
boolprof(object, gvar, instance = 0, range = 0)
}

\arguments{
  \item{object}{ The object created by the boolean command. }
  \item{gvar}{ Name of variable associated with coefficient of
     interest, or a constant ("cons"). }
  \item{instance}{ If variable occurs more than once in equation,
     permits user to specify which occurrence corresponds to the
     coefficient of interest. }
  \item{range}{ Range of points over which graph is plotted (e.g.,
  range=seq(0,1,0.01)) }
}
\references{ Braumoeller, Bear F. (2003) "Causal Complexity and the
     Study of Politics." \emph{Political Analysis} 11(3): 209-233. }

\author{
Bear F. Braumoeller, Harvard University, \email{bfbraum@fas.harvard.edu} \cr
Jacob Kline, Harvard University, \email{jkline@fas.harvard.edu}
}

\seealso{ \code{\link{boolean}}, \code{\link{boolprep}}, 
     and \code{\link{boolfirst}}. }

\examples{
library("boolean")
set.seed(50)
x1<-rnorm(1000)
x2<-rnorm(1000)
x3<-rnorm(1000)
x4<-rnorm(1000)
x5<-rnorm(1000)
x6<-rnorm(1000)
e1<-rnorm(1000)/3
e2<-rnorm(1000)/3
e3<-rnorm(1000)/3
y<-1-(1-pnorm(-2+0.33*x1+0.66*x2+1*x3+e1)*1-(pnorm(1+1.5*x4-0.25*x5+e2)*pnorm(1+0.2*x6+e3)))
y <- y>runif(1000)
answer <- boolean(y ~( ((cons+x1+x2+x3)|((cons+x4+x5)&(cons+x6))) ), method="probit")
boolprof(answer, "x1")
boolprof(answer, "cons", instance=2)
}
\keyword{logic}
\keyword{optimize}
\keyword{distribution}
\keyword{models}
\eof
\name{booltest}
\alias{booltest}
\alias{booltest-class}
\title{ Boolean Logit/Probit Objects }
\description{
  Boolean logit and probit procedures produce an object of class
  booltest.  Such an object contains slots @Calculus, @LogLik,
  @Variables, @Coefficients, @StandardErrors, @Iterations, @Hessian,
  @Gradient, @Zscore, @Probz, @Conf95lo, @Conf95hi, @pstructure, and
  @method (note that some slots may be left empty if the relevant
  information is not furnished by the maximizer).

  A booltest object may be summarized using summary().  More detailed
  output can be obtained by show().  The specialized functions
  \code{\link{boolfirst}} and \code{\link{boolprof}} produce plots of
  first differences and profile likelihoods, respectively.

  In addition, \code{plot()} produces a matrix of plots.  \code{plot()}
  takes a single argument, \code{panel}, that determines whether the
  matrix consists of first differences (\code{panel="boolfirst"}) or
  profile likelihoods (\code{panel="boolprof"}).  The default is first
  differences.
}
\references{
  Braumoeller, Bear F. (2003) "Causal Complexity and the Study
  of Politics." \emph{Political Analysis} 11(3): 209-233.
}

\author{
Bear F. Braumoeller, Harvard University, \email{bfbraum@fas.harvard.edu} \cr
Jacob Kline, Harvard University, \email{jkline@fas.harvard.edu}
}
\seealso{ \code{\link{boolean}}, \code{\link{boolfirst}}, and \code{\link{boolprof}}.
}

\keyword{logic}
\keyword{optimize}
\keyword{distribution}
\keyword{models}
\eof
\name{coef.boolean}
\docType{methods}
\alias{coef.boolean}
\alias{coef-methods}
\alias{coef,ANY-method}
\alias{coef,booltest-method}
\title{Coefficients for Boolean Logit and Probit Models}
\description{
'coef' method for objects of class '"booltest"'
}
\section{Usage}{\describe{

\item{object = "booltest"}{coef(object)}
}}
\keyword{methods}
\eof
\name{plot.boolean}
\docType{methods}
\alias{plot.boolean}
\alias{plot-methods}
\alias{plot,ANY-method}
\alias{plot,booltest-method}
\title{Plot Matrix for Boolean Logit and Probit Models}
\description{
'plot' method for objects of class '"booltest"'
}
\section{Usage}{\describe{
\item{object = "booltest"}{plot(object, panel = "boolfirst")}
}}
\arguments{
  \item{panel}{The individual graphs to be drawn in the plot matrix.
  Options are "\code{\link{boolfirst}}" for first differences and
  "\code{\link{boolprof}}" for profile likelihoods.}
}
\keyword{methods}

\eof
\name{show.boolean}
\docType{methods}
\alias{show.boolean}
\alias{show-methods}
\alias{show,ANY-method}
\alias{show,booltest-method}
\title{'show' Method for Boolean Logit and Probit Models}
\description{
'show' method for objects of class '"booltest"'
}
\section{Usage}{\describe{
\item{object = "booltest"}{show(object)}
}}
\keyword{methods}

\eof
\name{summary.boolean}
\docType{methods}
\alias{summary.boolean}
\alias{summary-methods}
\alias{summary,ANY-method}
\alias{summary,booltest-method}
\title{'summary' Method for Boolean Logit and Probit Models}
\description{
'summary' method for objects of class '"booltest"'
}
\section{Usage}{\describe{
\item{object = "booltest"}{summary(object)}
}}
\keyword{methods}

\eof
